from django.conf import settings
from django.contrib.auth.mixins import LoginRequiredMixin
from django.http import JsonResponse
from django.views.generic.base import TemplateView

from .activecollab import get_activecollab, post_activecollab


class IndexPageView(LoginRequiredMixin, TemplateView):
    template_name = 'activecollab_digger/index.html'


def tasks(request):
    if request.method == 'POST':
        return _post_task(request)

    return _get_tasks(request)


def _get_tasks(request):
    r = get_activecollab('projects/{}/tasks'.format(settings.AC_PROJECT_ID))

    if r.status_code != 200:
        return JsonResponse({'error': r.status_code,
                             'message': r.json()['message']})

    return JsonResponse(r.json())


def _post_task(request):
    params = {
        'name': request.POST.get('name'),
        'body': request.POST.get('body'),
        'created_by_id': settings.AC_USER
    }

    r = post_activecollab('projects/{}/tasks'.format(settings.AC_PROJECT_ID),
                          params=params)

    if r.status_code != 200:
        return JsonResponse({'error': r.status_code,
                             'message': r.json()['message']})

    return JsonResponse(r.json())



from django.conf import settings as s


def activecollab_digger(request):
    return {
        'AC_BASE_URL': s.AC_BASE_URL,
        'LOGIN_URL': s.LOGIN_URL,
        'PROJECT_NAME': s.PROJECT_NAME,
        'PROJECT_TITLE': s.PROJECT_TITLE
    }



"""
A setuptools based setup module.

See:
    https://packaging.python.org/en/latest/distributing.html
    https://github.com/pypa/sampleproject
    """

from codecs import open
from os import path

from setuptools import setup

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='django-activecollab-digger',

    version='0.6.3',

    description='Django ActiveCollab application',
    long_description=long_description,

    url='https://github.com/kingsdigitallab/django-activecollab-digger',

    author='King\'s Digital Lab',
    author_email='kdl-info@kcl.ac.uk',

    license='MIT',

    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Utilities',
    ],

    keywords='django activecollab',

    packages=['activecollab_digger'],

    install_requires=['requests[security]', 'simplejson'],

    package_data={
        'activecollab_digger': [
            'static/activecollab_digger/css/app.css',
            'static/activecollab_digger/js/app.js',
            'static/vendor/bulma/css/bulma.css',
            'static/vendor/bulma/css/bulma.css',
            'static/vendor/bulma/css/bulma.css.map',
            'static/vendor/font-awesome/css/font-awesome.min.css',
            'static/vendor/font-awesome/fonts/*.*',
            'static/vendor/tiny-cookie/tiny-cookie.min.js',
            'static/vendor/vue/dist/vue.min.js',
            'templates/activecollab_digger/*.html'
        ],
    },
)



import requests

import simplejson
from django.conf import settings

AC_HEADERS = {
    'X-Angie-AuthApiToken': settings.AC_TOKEN,
    'Content-Type': 'application/json; charset=utf-8'
}


def get_activecollab(api_path, params=None):
    r = requests.get('{}{}'.format(
        settings.AC_API_URL, api_path), params=simplejson.dumps(params),
        headers=AC_HEADERS)

    return r


def post_activecollab(api_path, params=None):
    r = requests.post('{}{}'.format(
        settings.AC_API_URL, api_path), data=simplejson.dumps(params),
        headers=AC_HEADERS)

    return r
